@@ -76,18 +76,36 @@ bool inline gjs_value_to_g_argument(JSContext* cx, JS::HandleValue value,
 }
 
 GJS_JSAPI_RETURN_CONVENTION
-bool gjs_value_from_g_argument(JSContext             *context,
+bool gjs_value_from_g_argument(JSContext* context,
                                JS::MutableHandleValue value_p,
-                               GITypeInfo            *type_info,
-                               GIArgument            *arg,
-                               bool                   copy_structs);
+                               GITypeInfo* type_info,
+                               GjsArgumentType argument_type,
+                               GITransfer transfer, GIArgument* arg);
 
 GJS_JSAPI_RETURN_CONVENTION
-bool gjs_value_from_explicit_array(JSContext             *context,
+inline bool gjs_value_from_g_argument(JSContext* cx,
+                                      JS::MutableHandleValue value_p,
+                                      GITypeInfo* type_info, GIArgument* arg,
+                                      bool copy_structs) {
+    return gjs_value_from_g_argument(
+        cx, value_p, type_info, GJS_ARGUMENT_ARGUMENT,
+        copy_structs ? GI_TRANSFER_EVERYTHING : GI_TRANSFER_NOTHING, arg);
+}
+
+GJS_JSAPI_RETURN_CONVENTION
+bool gjs_value_from_explicit_array(JSContext* context,
                                    JS::MutableHandleValue value_p,
-                                   GITypeInfo            *type_info,
-                                   GIArgument            *arg,
-                                   int                    length);
+                                   GITypeInfo* type_info, GITransfer transfer,
+                                   GIArgument* arg, int length);
+
+GJS_JSAPI_RETURN_CONVENTION
+inline bool gjs_value_from_explicit_array(JSContext* context,
+                                          JS::MutableHandleValue value_p,
+                                          GITypeInfo* type_info,
+                                          GIArgument* arg, int length) {
+    return gjs_value_from_explicit_array(context, value_p, type_info,
+                                         GI_TRANSFER_EVERYTHING, arg, length);
+}
 
 GJS_JSAPI_RETURN_CONVENTION
 bool gjs_g_argument_release(JSContext*, GITransfer, GITypeInfo*,
@@ -135,6 +153,7 @@ bool gjs_array_to_strv (JSContext   *context,
 
 GJS_JSAPI_RETURN_CONVENTION
 bool gjs_array_from_g_value_array(JSContext* cx, JS::MutableHandleValue value_p,
-                                  GITypeInfo* param_info, const GValue* gvalue);
+                                  GITypeInfo* param_info, GITransfer,
+                                  const GValue* gvalue);
 
 #endif  // GI_ARG_H_
