@@ -7,6 +7,7 @@
 
 #include <config.h>
 
+#include <stddef.h>  // for size_t
 #include <stdint.h>
 
 #include <memory>  // for unique_ptr
@@ -15,6 +16,7 @@
 #include <glib-object.h>
 #include <glib.h>
 
+#include <js/AllocPolicy.h>
 #include <js/GCHashTable.h>  // for GCHashMap
 #include <js/HashTable.h>    // for DefaultHasher
 #include <js/Id.h>
@@ -33,9 +35,6 @@ class JSTracer;
 namespace JS {
 class CallArgs;
 }
-namespace js {
-class SystemAllocPolicy;
-}
 
 /* To conserve memory, we have two different kinds of private data for GBoxed
  * JS wrappers: BoxedInstance, and BoxedPrototype. Both inherit from BoxedBase
@@ -160,6 +159,9 @@ class BoxedInstance
     friend class GIWrapperBase<BoxedBase, BoxedPrototype, BoxedInstance>;
     friend class BoxedBase;  // for field_getter, etc.
 
+    // Reserved slots
+    static const size_t PARENT_OBJECT = 1;
+
     bool m_allocated_directly : 1;
     bool m_owning_ptr : 1;  // if set, the JS wrapper owns the C memory referred
                             // to by m_ptr.
